v0.2.3 - 2024-09-22
-------------------

Misc
^^^^

- Use ``importlib.resources`` instead of ``pkg_resources``

  Drop Python 3.7 support.

  Add support for Python 3.12 (`#656 <https://github.com/swyddfa/esbonio/issues/656>`_)
- Drop Python 3.8 support

  Remove dependency on `nbformat` (`#879 <https://github.com/swyddfa/esbonio/issues/879>`_)


v0.2.2 - 2022-11-05
-------------------

Misc
^^^^

- Fix broken release pipeline (`#480 <https://github.com/swyddfa/esbonio/issues/480>`_)


v0.2.1 - 2022-11-05
-------------------

Misc
^^^^

- Add Python 3.11 support (`#470 <https://github.com/swyddfa/esbonio/issues/470>`_)


v0.2.0 - 2022-06-29
-------------------

Features
^^^^^^^^

- Add ``esbonio.relevant_to`` extension. (`#403 <https://github.com/swyddfa/esbonio/issues/403>`_)


v0.1.0 - 2021-11-26
-------------------

Features
^^^^^^^^

- Add initial implementation of the ``esbonio.tutorial`` extension. (`#261 <https://github.com/swyddfa/esbonio/issues/261>`_)


v0.0.2 - 2021-06-05
-------------------

Misc
^^^^

- No significant changes (`#206 <https://github.com/swyddfa/esbonio/issues/206>`_)


v0.0.1 - 2021-05-07v0.0.1 - 2021-05-07
-------------------

Misc
^^^^

- Initial release (`#146 <https://github.com/swyddfa/esbonio/issues/146>`_)
